@@ -6,9 +6,8 @@ import datetime
 import uuid
 
 __all__ = [
-  "dtstamp_factory",
-  "uid_factory",
-  "local_timezone",
+    "dtstamp_factory",
+    "uid_factory",
 ]
 
 
@@ -27,16 +26,17 @@ def uid_factory() -> str:
 
 def local_timezone() -> datetime.tzinfo:
     """Get the local timezone to use when converting date to datetime."""
-    local_tz = datetime.datetime.now().astimezone().tzinfo
-    if not local_tz:
-        return datetime.timezone.utc
-    return local_tz
+    if local_tz := datetime.datetime.now().astimezone().tzinfo:
+        return local_tz
+    return datetime.timezone.utc
 
 
-def normalize_datetime(value: datetime.date | datetime.datetime) -> datetime.datetime:
+def normalize_datetime(
+    value: datetime.date | datetime.datetime, tzinfo: datetime.tzinfo | None = None
+) -> datetime.datetime:
     """Convert date or datetime to a value that can be used for comparison."""
     if not isinstance(value, datetime.datetime):
         value = datetime.datetime.combine(value, MIDNIGHT)
     if value.tzinfo is None:
-        value = value.replace(tzinfo=local_timezone())
+        value = value.replace(tzinfo=tzinfo if tzinfo else local_timezone())
     return value
